@@ -12,18 +12,19 @@ except:
 
 class OrderManager:
     class Memory:
-        def __init__(self, tickers, wallet, positions, orders):
+        def __init__(self, tickers, wallet, positions, orders, misc):
             self.tickers = tickers
             self.wallet = wallet
             self.positions = positions
             self.orders = orders
+            self.misc = misc
 
     def __init__(self, GUID, data_path, data_source, config, open_orders):
         self.open_orders = open_orders
         self.log = None
         self.GUID = GUID
         self.wallet = float(config["start_wallet"])
-        self.threshold = float(config["thresh_percent"]) * self.wallet  
+        self.threshold = float(config["thresh_percent"]) * self.wallet  #   ex, 25,000 * .05 = 125
         self.data_source = data_source
         self.tickers = config["tickers"].split(",")
         self.orders = []
@@ -43,49 +44,18 @@ class OrderManager:
             self.init_buy[t] = True # Not used rn
             self.positions[t] = 0
         self.mem_file = data_path + "algo_mem/{}.pkl".format(GUID)
-    def _buy(self, ticker, quantity, price):
-        capital_out = 0
-        # Goes through local order list and updates using live list
-        for order in self.orders:
-            if self.open_orders.get(order) != None:
-                if self.open_orders[order][0] == "buy":
-                    capital_out += self.open_orders[order][1] * self.open_orders[order][2]   #Add up capital_out
-            else:
-                self.orders.remove(order)
-        # If capital out exceeds our threshold we will cancel orders starting from the oldest unitl we have enough open capital
-        while capital_out > self.threshold:
-            id = self.orders[0]
-            side = self.open_orders[id][0]
-            qty = self.open_orders[id][1]
-            limit_price = self.open_orders[id][2]
-            ticker = self.open_orders[id][3]
-            #If the oldest order is a buy
-            if side == "buy":
-                print("Canceling Buy Order Id: {}, Buy_Capital_out: {}".format(id, capital_out-total_price))
-                self.data_source.cancel_order(id)
-                total_price = qty * limit_price 
-                self.wallet += total_price
-                self.positions[ticker] -= qty
-                self.orders.remove(id)
-                capital_out -= total_price
-            #If the oldest order is a sell
-            else:
-                print("Canceling Sell Order Id: {}, Ticker: {}, Shares Returned: {}".format(id, ticker, qty))
-                self.data_source.cancel_order(id)
-                total_price = qty * limit_price  
-                self.wallet -= total_price
-                self.positions[ticker] += qty
-                self.orders.remove(id)
-
-
-
-        if self.wallet > price:
+        self.misc = {}
+    def _buy(self, ticker, quantity, price=0, type='limit'):
+        
+        self._cancel_open_orders(side='buy')
+        
+        if self.wallet > price * quantity:
             if not self.quick_test:
                 response = self.data_source.submit_order(
                 ticker=ticker,
                 quantity=quantity,
                 side='buy',
-                type='limit',
+                type=type,
                 limit_price=price,
                 time_in_force='gtc'
                 )
@@ -95,53 +65,20 @@ class OrderManager:
 
             self.positions[ticker] += quantity
             self.wallet -= price*quantity
-            self.log.trade("Wallet Value: {}       -{}".format(self.wallet, price))
+            self.log.trade("Limit Buy {} of {} at {} per share".format(ticker, quantity, price))
+            self.log.trade("Wallet Value: {}         SPENT -{}".format(self.wallet, price*quantity))
         else:
             self.log.warn(" ! NOT ENOUGH MONEY ! Wallet Value: {}".format(self.wallet))
-    def _sell(self, ticker, quantity, price):
-        capital_out = 0
-        # Goes through local order list and updates using live list
-        for order in self.orders:
-            if self.open_orders.get(order) != None:
-                if self.open_orders[order][0] == "sell":
-                    capital_out += self.open_orders[order][1] * self.open_orders[order][2]   #Add up capital_out
-            else:
-                self.orders.remove(order)
-        # If capital out exceeds our threshold we will cancel orders starting from the oldest unitl we have enough open capital
-        print("Threshhold: {} , Capital Out: {}".format(self.threshold, capital_out))
-        while capital_out > self.threshold:
-            id = self.orders[0]
-            side = self.open_orders[id][0]
-            qty = self.open_orders[id][1]
-            limit_price = self.open_orders[id][2]
-            ticker = self.open_orders[id][3]
-            #If the oldest order is a buy
-            if side == "buy":
-                print("Canceling Buy Order Id: {}, Ticker: {}, Shares Given Back: {}".format(id, ticker, qty))
-                self.data_source.cancel_order(id)
-                total_price = qty * limit_price 
-                self.wallet += total_price
-                self.positions[ticker] -= qty
-                self.orders.remove(id)    
-            #If the oldest order is a sell
-            else:
-                print("Canceling Sell Order Id: {}, Sell_Capital_out: {}".format(id, capital_out-total_price))
-                self.data_source.cancel_order(id)
-                total_price = qty * limit_price  
-                self.wallet -= total_price
-                self.positions[ticker] += qty
-                self.orders.remove(id)
-                capital_out -= total_price
-
-
-
+            
+    def _sell(self, ticker, quantity, price=0, type='limit'):
+        self._cancel_open_orders(side='sell')
         if self.positions[ticker] >= quantity:
             if not self.quick_test:
                 response = self.data_source.submit_order(
                 ticker=ticker,
                 quantity=quantity,
                 side='sell',
-                type='limit',
+                type=type,
                 limit_price=price,
                 time_in_force='gtc'
                 )
@@ -150,14 +87,54 @@ class OrderManager:
 
             self.positions[ticker] -= quantity
             self.wallet += price*quantity
-            self.log.trade("Wallet Value: {}       +{}".format(self.wallet, price))
+            self.log.trade("Limit Sell {} of {} at {} per share".format(ticker, quantity, price))
+            self.log.trade("Wallet Value: {}          MADE  +{}".format(self.wallet, price*quantity))
+
         else:
             self.log.warn(" ! NOT ENOUGH SHARES ! Wallet Value: {}".format(self.wallet))
+    
+    def _cancel_open_orders(self, side='buy'):
+        self.log.info("Checking for open orders on {} side".format(side))
+        capital_out = 0
+        # Goes through local order list and updates using live list
+        
+        for order in self.orders:
+            if self.open_orders.get(order) != None:
+                if self.open_orders[order][0] == side:
+                    capital_out += self.open_orders[order][1] * self.open_orders[order][2]   #Add up capital_out
+            else:
+                self.orders.remove(order)
+        # If capital out exceeds our threshold we will cancel orders starting from the oldest unitl we have enough open capital
+        while capital_out > self.threshold:
+            id = self.orders[0]
+            side = self.open_orders[id][0]
+            qty = self.open_orders[id][1]
+            limit_price = self.open_orders[id][2]
+            ticker = self.open_orders[id][3]
+            #If the oldest order is a buy
+            if side == "buy":
+                self.log.info("Canceling Buy Order Id: {}, Buy_Capital_out: {}".format(id, capital_out-total_price))
+                self.data_source.cancel_order(id)
+                total_price = qty * limit_price 
+                self.wallet += total_price
+                self.positions[ticker] -= qty
+                self.orders.remove(id)
+                capital_out -= total_price
+            #If the oldest order is a sell
+            else:
+                self.log.info("Canceling Sell Order Id: {}, Ticker: {}, Shares Returned: {}".format(id, ticker, qty))
+                self.data_source.cancel_order(id)
+                total_price = qty * limit_price  
+                self.wallet -= total_price
+                self.positions[ticker] += qty
+                self.orders.remove(id)
+        self.log.info("Finished checek for open orders")
+        
     def save_algo(self):
         try:
             if self.quick_test: raise Exception("Test mode on. No Saving.")
             fs = open(self.mem_file ,"w+b")
-            to_save = self.Memory(self.tickers, self.wallet, self.positions, self.orders)
+            to_save = self.Memory(self.tickers, self.wallet, self.positions, self.orders, self.misc)
             pickle.dump(to_save,fs)
             fs.close()
             self.log.info("MEM_SAVE SUCCESSFUL")
@@ -174,6 +151,7 @@ class OrderManager:
             self.wallet = from_save.wallet
             self.positions = from_save.positions
             self.orders = from_save.orders
+            self.misc = from_save.misc
             self.log.info("Found Memory ||     wallet:{}".format(self.wallet))
             fs.close()
         except Exception as e:
@@ -229,6 +207,8 @@ class DailyRebalancer(OrderManager):
         
     def rebalance(self, to_sell, to_buy):
         self.log.info("Started Rebalancing on Order Manager")
+        self.log.info("to_sell : {}".format(to_sell))
+        self.log.info("to_buy  : {}".format(to_buy))
         # Go through each ticker and wallet value. Calculate how much 
         # value of each ticker i should have
         for sell in to_sell:
