@@ -20,6 +20,8 @@ class AlgoLogger:
         self.warn_print =  " [  -------- WARN  --------  ] "
         self.sep =         " [  -----------------------  ] "
         self.fn = data_path + "daily_logs/prog/{}.txt".format(datetime.today().strftime('%Y-%m-%d'))
+        if name:
+            self.set_name(name)
 
     def info(self, output):
         self.to_print.append(self.info_print + str(output))
@@ -35,10 +37,10 @@ class AlgoLogger:
         self.output()
 
     def set_name(self, name):
-        self.error_print = " [ " + name + " -------- ERROR --------  ] "
-        self.trade_print = " [ " + name + " -------- TRADE --------  ] "
-        self.info_print =  " [ " + name + " -------- INFO  --------  ] "
-        self.warn_print =  " [ " + name + " -------- WARN  --------  ] "
+        self.error_print = " [ {0:<15} -------- ERROR --------  ] ".format(name)
+        self.trade_print = " [ {0:<15} -------- TRADE --------  ] ".format(name)
+        self.info_print =  " [ {0:<15} -------- INFO  --------  ] ".format(name)
+        self.warn_print =  " [ {0:<15} -------- WARN  --------  ] ".format(name)
 
     def output(self):
         for p in self.to_print:
@@ -90,7 +92,7 @@ class Backtester():
         self.run()
 
     # dictates if algo is done overall
-    def run(self, tick_period):
+    def run(self):
         if self.cur_time >= self.end_utc or self.algo_done:
             self.algo_done = True
             self.is_open = False
@@ -141,7 +143,11 @@ class Backtester():
             return True
         else:
             return False
-
+    # def get_date(self):
+    #     self.cur_utc = datetime.fromtimestamp(self.cur_time, timezone(-timedelta(hours=4)))
+    #     self.current_date = "{0:0=4d}".format(self.cur_utc.year)+"-"+"{0:0=2d}".format(self.cur_utc.month)+"-"+"{0:0=2d}".format(self.cur_utc.day)
+    #     return self.current_date
+        
     def get_clock(self):
         return {"is_open" : self.is_open}
 
@@ -151,7 +157,13 @@ class Backtester():
         return ret
 
     def get_position(self, ticker):
-        ret = {"qty" : self.positions[ticker]}
+        # print("get position")
+        price = self.cur_df[ticker].loc[self.cur_utc]["close"]
+        qty =  self.positions[ticker]
+        # print(price)
+        # print(qty)
+        
+        ret = {"qty" : qty,"current_price" : price, "market_value" : price*qty, }
         return ret
 
     def get_account(self):
@@ -196,15 +208,20 @@ class DataSource:
                     else:
                         time.sleep(tick_period)
         if (self.mode == backtest):
-            self.backtester.run(tick_period)
+            self.backtester.run()
 
 
     def get_clock(self):
         if (self.mode == backtest):
             return self.backtester.get_clock()
         clk = self.api_endpoint.get_clock()
-        ret = {"is_open" : clk.is_open}
+        ret = {"is_open" : clk.is_open, "timestamp" : clk.timestamp}
         return ret
+        
+    def get_date(self):
+        self.cur_utc = datetime.fromtimestamp(self.get_clock()['timestamp'], timezone(-timedelta(hours=4)))
+        self.current_date = "{0:0=4d}".format(self.cur_utc.year)+"-"+"{0:0=2d}".format(self.cur_utc.month)+"-"+"{0:0=2d}".format(self.cur_utc.day)
+        return self.current_date
 
     def get_last_trade(self, ticker):
         if (self.mode == backtest):
@@ -300,8 +317,10 @@ class Stream:
             self.conn  = tradeapi.stream2.StreamConn(key_id, secret_key, base_url)
         except Exception as e:
             log.error("CANNOT ESTABLISH WEB SOCKET CONNECTION:          " + str(e))
+            
         @self.conn.on(r'^trade_updates$')
         async def on_trade_updates(conn, channel, trade):
+            log.set_name("UTIL")
             if trade.event == 'new':
                 side = trade.order['side']
                 symbol = trade.order['symbol']
@@ -309,21 +328,21 @@ class Stream:
                 qty = trade.order['qty']
                 limit_price = trade.order['limit_price']
                 self.open_orders[id] = (side, qty, limit_price, symbol)
-                print(len(self.open_orders))
+                log.info("New Order - {}  {}  {}, # still open: {}".format(id, symbol, side, len(self.open_orders)))
             elif trade.event == 'canceled':
                 del self.open_orders[trade.order['id']]
-                print(len(self.open_orders))
+                log.info("Canceled Order - {}, # still open: {}".format(id, len(self.open_orders)))
             elif trade.event == 'fill':
                 del self.open_orders[trade.order['id']]
-                print(len(self.open_orders))
+                log.info("Filled Order - {}, # still open: {}".format(id, len(self.open_orders)))
             elif trade.event == 'expired':
                 del self.open_orders[trade.order['id']]
-                print(len(self.open_orders))
+                log.info("Expired Order - {}, # still open: {}".format(id, len(self.open_orders)))
 
 
     def ws_start(self):
         self.conn.run(['trade_updates'])
         time.sleep(2)
 
-    def get_open_orders(self ):
+    def get_open_orders(self):
         return self.open_orders
